==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleProvidersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleProvidersFluent<A extends ConsoleProvidersFluent<A>> extends BaseFluent<A>{
  public ConsoleProvidersFluent() {
  }
  public ConsoleProvidersFluent(ConsoleProviders instance) {
    instance = (instance != null ? instance : new ConsoleProviders());

    if (instance != null) {
      this.withStatuspage(instance.getStatuspage());
      this.withStatuspage(instance.getStatuspage());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private StatuspageProviderBuilder statuspage;
  private Map<String,Object> additionalProperties;
  public StatuspageProvider buildStatuspage() {
    return this.statuspage!=null ?this.statuspage.build():null;
  }
  public A withStatuspage(StatuspageProvider statuspage) {
    _visitables.get("statuspage").remove(this.statuspage);
    if (statuspage!=null){ this.statuspage= new StatuspageProviderBuilder(statuspage); _visitables.get("statuspage").add(this.statuspage);} else { this.statuspage = null; _visitables.get("statuspage").remove(this.statuspage); } return (A) this;
  }
  public boolean hasStatuspage() {
    return this.statuspage != null;
  }
  public A withNewStatuspage(String pageID) {
    return (A)withStatuspage(new StatuspageProvider(pageID));
  }
  public StatuspageNested<A> withNewStatuspage() {
    return new StatuspageNested(null);
  }
  public StatuspageNested<A> withNewStatuspageLike(StatuspageProvider item) {
    return new StatuspageNested(item);
  }
  public StatuspageNested<A> editStatuspage() {
    return withNewStatuspageLike(java.util.Optional.ofNullable(buildStatuspage()).orElse(null));
  }
  public StatuspageNested<A> editOrNewStatuspage() {
    return withNewStatuspageLike(java.util.Optional.ofNullable(buildStatuspage()).orElse(new StatuspageProviderBuilder().build()));
  }
  public StatuspageNested<A> editOrNewStatuspageLike(StatuspageProvider item) {
    return withNewStatuspageLike(java.util.Optional.ofNullable(buildStatuspage()).orElse(item));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleProvidersFluent that = (ConsoleProvidersFluent) o;
    if (!java.util.Objects.equals(statuspage, that.statuspage)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(statuspage,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (statuspage != null) { sb.append("statuspage:"); sb.append(statuspage + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class StatuspageNested<N> extends StatuspageProviderFluent<StatuspageNested<N>> implements Nested<N>{
    StatuspageNested(StatuspageProvider item) {
      this.builder = new StatuspageProviderBuilder(this, item);
    }
    StatuspageProviderBuilder builder;
    public N and() {
      return (N) ConsoleProvidersFluent.this.withStatuspage(builder.build());
    }
    public N endStatuspage() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleProvidersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ConsoleProvidersFluent<A extends ConsoleProvidersFluent<A>> extends BaseFluent<A>{
  public ConsoleProvidersFluent() {
  }
  
  public ConsoleProvidersFluent(ConsoleProviders instance) {
    this.copyInstance(instance);
  }
  private StatuspageProviderBuilder statuspage;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ConsoleProviders instance) {
    instance = (instance != null ? instance : new ConsoleProviders());
  
    if (instance != null) {
        this.withStatuspage(instance.getStatuspage());
        this.withStatuspage(instance.getStatuspage());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public StatuspageProvider buildStatuspage() {
    return this.statuspage!=null ?this.statuspage.build():null;
  }
  
  public A withStatuspage(StatuspageProvider statuspage) {
    _visitables.get("statuspage").remove(this.statuspage);
    if (statuspage!=null){ this.statuspage= new StatuspageProviderBuilder(statuspage); _visitables.get("statuspage").add(this.statuspage);} else { this.statuspage = null; _visitables.get("statuspage").remove(this.statuspage); } return (A) this;
  }
  
  public boolean hasStatuspage() {
    return this.statuspage != null;
  }
  
  public A withNewStatuspage(String pageID) {
    return (A)withStatuspage(new StatuspageProvider(pageID));
  }
  
  public StatuspageNested<A> withNewStatuspage() {
    return new StatuspageNested(null);
  }
  
  public StatuspageNested<A> withNewStatuspageLike(StatuspageProvider item) {
    return new StatuspageNested(item);
  }
  
  public StatuspageNested<A> editStatuspage() {
    return withNewStatuspageLike(java.util.Optional.ofNullable(buildStatuspage()).orElse(null));
  }
  
  public StatuspageNested<A> editOrNewStatuspage() {
    return withNewStatuspageLike(java.util.Optional.ofNullable(buildStatuspage()).orElse(new StatuspageProviderBuilder().build()));
  }
  
  public StatuspageNested<A> editOrNewStatuspageLike(StatuspageProvider item) {
    return withNewStatuspageLike(java.util.Optional.ofNullable(buildStatuspage()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleProvidersFluent that = (ConsoleProvidersFluent) o;
    if (!java.util.Objects.equals(statuspage, that.statuspage)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(statuspage,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (statuspage != null) { sb.append("statuspage:"); sb.append(statuspage + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class StatuspageNested<N> extends StatuspageProviderFluent<StatuspageNested<N>> implements Nested<N>{
    StatuspageNested(StatuspageProvider item) {
      this.builder = new StatuspageProviderBuilder(this, item);
    }
    StatuspageProviderBuilder builder;
    
    public N and() {
      return (N) ConsoleProvidersFluent.this.withStatuspage(builder.build());
    }
    
    public N endStatuspage() {
      return and();
    }
    
  
  }

}
